==> estateplat-common-1.2.4-20201113.014416-502-sources.jar: cn/gtmap/estateplat/model/exchange/unidofrmity/KttGyJzxBdc.java <==
package cn.gtmap.estateplat.model.exchange.unidofrmity;

import cn.gtmap.estateplat.model.exchange.national.KttGyJzx;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;
import cn.gtmap.estateplat.utils.JaxbStringNoNullAdapter;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;

public class KttGyJzxBdc extends KttGyJzx {
    private String dfjzxlbdm;
    private String dfjzxlbmc;
    private String dfjzxwzdm;
    private String dfjzxwzmc;
    private String dfjxxzdm;
    private String dfjxxzmc;
    @XmlAttribute(
            name = "DFJZXLBDM"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfjzxlbdm() {
        return dfjzxlbdm;
    }

    public void setDfjzxlbdm(String dfjzxlbdm) {
        this.dfjzxlbdm = dfjzxlbdm;
    }
    @XmlAttribute(
            name = "DFJZXLBMC"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfjzxlbmc() {
        return dfjzxlbmc;
    }

    public void setDfjzxlbmc(String dfjzxlbmc) {
        this.dfjzxlbmc = dfjzxlbmc;
    }
    @XmlAttribute(
            name = "DFJZXWZDM"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfjzxwzdm() {
        return dfjzxwzdm;
    }

    public void setDfjzxwzdm(String dfjzxwzdm) {
        this.dfjzxwzdm = dfjzxwzdm;
    }
    @XmlAttribute(
            name = "DFJZXWZMC"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfjzxwzmc() {
        return dfjzxwzmc;
    }

    public void setDfjzxwzmc(String dfjzxwzmc) {
        this.dfjzxwzmc = dfjzxwzmc;
    }
    @XmlAttribute(
            name = "DFJXXZDM"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfjxxzdm() {
        return dfjxxzdm;
    }

    public void setDfjxxzdm(String dfjxxzdm) {
        this.dfjxxzdm = dfjxxzdm;
    }
    @XmlAttribute(
            name = "DFJXXZMC"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfjxxzmc() {
        return dfjxxzmc;
    }

    public void setDfjxxzmc(String dfjxxzmc) {
        this.dfjxxzmc = dfjxxzmc;
    }
}

==> estateplat-common-1.2.4-20211213.072500-951-sources.jar: cn/gtmap/estateplat/model/exchange/unidofrmity/KttGyJzxBdc.java <==
package cn.gtmap.estateplat.model.exchange.unidofrmity;

import cn.gtmap.estateplat.model.exchange.national.KttGyJzx;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;
import cn.gtmap.estateplat.utils.JaxbStringNoNullAdapter;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;

public class KttGyJzxBdc extends KttGyJzx {
    private String dfjzxlbdm;
    private String dfjzxlbmc;
    private String dfjzxwzdm;
    private String dfjzxwzmc;
    private String dfjxxzdm;
    private String dfjxxzmc;
    @XmlAttribute(
            name = "DFJZXLBDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfjzxlbdm() {
        return dfjzxlbdm;
    }

    public void setDfjzxlbdm(String dfjzxlbdm) {
        this.dfjzxlbdm = dfjzxlbdm;
    }
    @XmlAttribute(
            name = "DFJZXLBMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfjzxlbmc() {
        return dfjzxlbmc;
    }

    public void setDfjzxlbmc(String dfjzxlbmc) {
        this.dfjzxlbmc = dfjzxlbmc;
    }
    @XmlAttribute(
            name = "DFJZXWZDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfjzxwzdm() {
        return dfjzxwzdm;
    }

    public void setDfjzxwzdm(String dfjzxwzdm) {
        this.dfjzxwzdm = dfjzxwzdm;
    }
    @XmlAttribute(
            name = "DFJZXWZMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfjzxwzmc() {
        return dfjzxwzmc;
    }

    public void setDfjzxwzmc(String dfjzxwzmc) {
        this.dfjzxwzmc = dfjzxwzmc;
    }
    @XmlAttribute(
            name = "DFJXXZDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfjxxzdm() {
        return dfjxxzdm;
    }

    public void setDfjxxzdm(String dfjxxzdm) {
        this.dfjxxzdm = dfjxxzdm;
    }
    @XmlAttribute(
            name = "DFJXXZMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfjxxzmc() {
        return dfjxxzmc;
    }

    public void setDfjxxzmc(String dfjxxzmc) {
        this.dfjxxzmc = dfjxxzmc;
    }
}
